==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/MethodFinder.h <==
// class gnu.java.beans.decoder.MethodFinder

// class file dependencies
// @dep_class 6f5feef708ac05d7 gnu_java_beans_decoder_MethodFinder
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_MethodFinder_H_
#define _JC_gnu_java_beans_decoder_MethodFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Constructor$object;
struct _jc_java_lang_reflect_Method$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$sub_refs	_jc_gnu_java_beans_decoder_MethodFinder$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs	_jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$refs	_jc_gnu_java_beans_decoder_MethodFinder$refs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$nonrefs	_jc_gnu_java_beans_decoder_MethodFinder$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$object	_jc_gnu_java_beans_decoder_MethodFinder$object;

typedef struct _jc_gnu_java_beans_decoder_MethodFinder$fields_struct	_jc_gnu_java_beans_decoder_MethodFinder$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_MethodFinder$vmethods	_jc_gnu_java_beans_decoder_MethodFinder$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_MethodFinder$vtable	_jc_gnu_java_beans_decoder_MethodFinder$vtable;
typedef const struct _jc_gnu_java_beans_decoder_MethodFinder$vtype	_jc_gnu_java_beans_decoder_MethodFinder$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_MethodFinder$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Boolean;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Byte;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Character;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Double;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Float;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Integer;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Long;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Short;
	struct _jc_java_util_HashMap$object	*typeMapping;
};
extern _jc_gnu_java_beans_decoder_MethodFinder$fields_struct _jc_gnu_java_beans_decoder_MethodFinder$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_MethodFinder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_MethodFinder$object *);

// Static methods
extern void _jc_gnu_java_beans_decoder_MethodFinder$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_decoder_MethodFinder$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern _jc_object_array *_jc_gnu_java_beans_decoder_MethodFinder$method$getArgumentTypes$dda981b4c021ac2b(_jc_env *, struct _jc_object_array *);
extern struct _jc_java_lang_reflect_Constructor$object *_jc_gnu_java_beans_decoder_MethodFinder$method$getConstructor$c6f6cf118926748f(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object_array *);
extern struct _jc_java_lang_reflect_Method$object *_jc_gnu_java_beans_decoder_MethodFinder$method$getMethod$03280dcb95606a33(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);
extern jboolean _jc_gnu_java_beans_decoder_MethodFinder$method$matchingArgumentTypes$a89eac6b4a7f79a0(_jc_env *, struct _jc_object_array *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_MethodFinder$vmethods {
};

// Vtable
struct _jc_gnu_java_beans_decoder_MethodFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_MethodFinder$vmethods	gnu_java_beans_decoder_MethodFinder;
};

// Vtype
struct _jc_gnu_java_beans_decoder_MethodFinder$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_MethodFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_MethodFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_MethodFinder$refs {
    _jc_gnu_java_beans_decoder_MethodFinder$sub_refs	gnu_java_beans_decoder_MethodFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_MethodFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs	gnu_java_beans_decoder_MethodFinder;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_MethodFinder$object {
	_jc_gnu_java_beans_decoder_MethodFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_MethodFinder$vtype	*vtype;
	_jc_gnu_java_beans_decoder_MethodFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_MethodFinder$vtype _jc_gnu_java_beans_decoder_MethodFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_MethodFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_MethodFinder$class_object;

#endif	/* _JC_gnu_java_beans_decoder_MethodFinder_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/MethodFinder.h <==
// class gnu.java.beans.decoder.MethodFinder

// class file dependencies
// @dep_class 6f5feef708ac05d7 gnu_java_beans_decoder_MethodFinder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_MethodFinder_H_
#define _JC_gnu_java_beans_decoder_MethodFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Constructor$object;
struct _jc_java_lang_reflect_Method$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$sub_refs	_jc_gnu_java_beans_decoder_MethodFinder$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs	_jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$refs	_jc_gnu_java_beans_decoder_MethodFinder$refs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$nonrefs	_jc_gnu_java_beans_decoder_MethodFinder$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_MethodFinder$object	_jc_gnu_java_beans_decoder_MethodFinder$object;

typedef struct _jc_gnu_java_beans_decoder_MethodFinder$fields_struct	_jc_gnu_java_beans_decoder_MethodFinder$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_MethodFinder$vmethods	_jc_gnu_java_beans_decoder_MethodFinder$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_MethodFinder$vtable	_jc_gnu_java_beans_decoder_MethodFinder$vtable;
typedef const struct _jc_gnu_java_beans_decoder_MethodFinder$vtype	_jc_gnu_java_beans_decoder_MethodFinder$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_MethodFinder$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Boolean;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Byte;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Character;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Double;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Float;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Integer;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Long;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Short;
	struct _jc_java_util_HashMap$object	*typeMapping;
};
extern _jc_gnu_java_beans_decoder_MethodFinder$fields_struct _jc_gnu_java_beans_decoder_MethodFinder$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_MethodFinder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_MethodFinder$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_beans_decoder_MethodFinder$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_decoder_MethodFinder$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_beans_decoder_MethodFinder$method$getArgumentTypes$dda981b4c021ac2b(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_reflect_Constructor$object *_jc_gnu_java_beans_decoder_MethodFinder$method$getConstructor$c6f6cf118926748f(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_reflect_Method$object *_jc_gnu_java_beans_decoder_MethodFinder$method$getMethod$03280dcb95606a33(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_MethodFinder$method$matchingArgumentTypes$a89eac6b4a7f79a0(_jc_env *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_MethodFinder$vmethods {
};

// Vtable
struct _jc_gnu_java_beans_decoder_MethodFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_MethodFinder$vmethods	gnu_java_beans_decoder_MethodFinder;
};

// Vtype
struct _jc_gnu_java_beans_decoder_MethodFinder$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_MethodFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_MethodFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_MethodFinder$refs {
    _jc_gnu_java_beans_decoder_MethodFinder$sub_refs	gnu_java_beans_decoder_MethodFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_MethodFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_MethodFinder$sub_nonrefs	gnu_java_beans_decoder_MethodFinder;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_MethodFinder$object {
	_jc_gnu_java_beans_decoder_MethodFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_MethodFinder$vtype	*vtype;
	_jc_gnu_java_beans_decoder_MethodFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_MethodFinder$vtype _jc_gnu_java_beans_decoder_MethodFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_MethodFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_MethodFinder$class_object;

#endif	/* _JC_gnu_java_beans_decoder_MethodFinder_H_ */
